CNGEheatmaps(CNdata, GEdata, location = "mode", colorbreaks = "equiquantiles")cghCall, containing (among others) annotion and call probabilities. Features should be matched with those of the
accompanying ExpressionSet-object (as may be done using the matchCGHcall2ExpressionSet-function). ExpressionSet. Features should be matched with those of the accompanying
cghCall-object (as may be done using the matchCGHcall2ExpressionSet-function). median, mean, or mode) specifying how the center of the gene expression heatmap color-scheme is determined. equiquantiles or equidistant. CGHregions-package.
Consequently, within a segment the DNA copy number for one sample is constant, but may vary between samples. Note that a
region may comprise of a whole chromosome, but also of a focal amplication. It is the DNA copy number signature of the segments that is
depicted in the heatmap of the DNA copy number data. For the gene expression heatmap segments as constructed for the array CGH data are adopted. For each segment-sample combination the expression levels of the genes that map to that segment are averaged. Next, the gene expression data is also collapsed to the segment format. It is this collapsed and averaged expression data that is depicted in the corresponding heatmap.
Van Wieringen, W.N., Van de Wiel, M.A. (2009), "Non-parametric testing for DNA copy number induced differential mRNA gene expression", Biometrics, 65(1), 19-29.
cghCall, ExpressionSet, matchCGHcall2ExpressionSet, profilesPlot, # load data
data(pollackCN16)
data(pollackGE16)
# plot heatmaps
CNGEheatmaps(pollackCN16, pollackGE16, location = "mode", colorbreaks = "equiquantiles")
Run the code above in your browser using DataLab