Learn R Programming

sigaR (version 1.18.0)

cisEffectTune: Pre-test and tuning.

Description

Decides which test to perform: loss vs. no-loss (tumor surpressor) or no-gain vs gain (proto-onco). Followed by a tuning algorithm that enhances the overal power of the FDR procedure by excluding genes with either unbalanced (many samples having a high call probability of, say, a loss) or imprecise (many call probabilities close to 0.5) soft calls, which is likely to increase the probability of detection for genes with a more favorable call probability distribution.

Usage

cisEffectTune(CNdata, GEdata, testStatistic, nGenes=250, nPerm=250, minCallProbMass=0.10, verbose=TRUE)

Arguments

CNdata
Object of class cghCall, containing (among others) annotion and call probabilities. Features should be matched with those of the accompanying ExpressionSet-object (as may be done using the matchAnn2Ann-function).
GEdata
Object of class ExpressionSet. Features should be matched with those of the accompanying cghCall-object (as may be done using the matchAnn2Ann-function).
testStatistic
Test statistic to be used, either "wcvm" or "wmw", the weighted Cramer-Von Mises and the weighted Mann-Whitney test statistic, respectively.
nGenes
Number of genes used for tuning.
nPerm
Number of permutation used for tuning.
minCallProbMass
A number inbetween 0 and 1. Genes with a marginal call probabilities in one of the classes smaller than minCallProbMass are discarded from further analysis. Effectively, this ensures identifiability of copy number effect on expression.
verbose
Boolean to suppress output, either FALSE and TRUE.

Value

A numeric-object with the genes selected for testing. Numbering corresponds to genes of the pre-tuned, but matched data set.

References

Van Wieringen, W.N., Van de Wiel, M.A. (2009), "Non-parametric testing for DNA copy number induced differential mRNA gene expression", Biometrics, 65(1), 19-29.

See Also

matchAnn2Ann, cisEffectTest

Examples

Run this code
# load data
data(pollackCN16)
data(pollackGE16)

# select genes that are likely to have a significant genomic cis-effect on expression levels
genes2test <- cisEffectTune(pollackCN16, pollackGE16, "wmw", nGenes=50, nPerm=50)

Run the code above in your browser using DataLab