Learn R Programming

sigaR (version 1.18.0)

merge2cghCalls: Merge two cghCall-objects into one cghCall-object

Description

Merge two cghCall-objects into one cghCall-object.

Usage

merge2cghCalls(CNdata1, CNdata2, verbose=TRUE)

Arguments

CNdata1
Object of class cghCall.
CNdata2
Object of class cghCall.
verbose
Logical indicator: should intermediate output be printed on the screen?

Value

Object of class cghCall, restricted to the specified subset of features.

Details

Data of the two objects is assumed to originate from the same samples, and are presented in the same order.

Only the experimental data and annotation information is inherited by the merged object.

References

Van de Wiel, M.A., Kim, K.I., Vosse, S.J., Van Wieringen, W.N., Wilting, S.M. , Ylstra, B. (2007), "CGHcall: an algorithm for calling aberrations for multiple array CGH tumor profiles", Bioinformatics, 23, 892-894.

Van Wieringen, W.N., Unger, K., Leday, G.G.R., Krijgsman, O., De Menezes, R.X., Ylstra, B., Van de Wiel, M.A. (2012), "Matching of array CGH and gene expression microarray features for the purpose of integrative analysis", BMC Bioinformatics, 13:80.

See Also

cghCall.

Examples

Run this code
# load data
data(pollackCN16) 

# create two cghCall-objects
ids1 <- sample(1:dim(pollackCN16)[1], 10) 
CNdata1 <- pollackCN16[ids1,] 
CNdata2 <- pollackCN16[-ids1,] 

# order the copy number data genomically
pollackCN16 <- merge2cghCalls(CNdata1, CNdata2) 

Run the code above in your browser using DataLab