Learn R Programming

sigaR (version 1.18.0)

uniqGenomicInfo: Unique genomic location information

Description

Finds unique genomic location information.

Usage

uniqGenomicInfo(chr, bpstart, bpend, verbose = FALSE)

Arguments

chr
Object of class numeric containing chromosome information of features.
bpstart
Object of class numeric containing start base pair information of features. Of same length as chr.
bpend
Object of class numeric containing end base pair information of features. Of same length as chr.
verbose
Logical indicator: should intermediate output be printed on the screen?

Value

An object of class list. Each list item is a four-column matrix with the matched features information. The first column contains feature numbers of features with identical genomic location. The second, third and fourth column contain the chromosome, start and end base pair information of the features (should be the same for each feature).

References

Van Wieringen, W.N., Unger, K., Leday, G.G.R., Krijgsman, O., De Menezes, R.X., Ylstra, B., Van de Wiel, M.A. (2012), "Matching of array CGH and gene expression microarray features for the purpose of integrative analysis", BMC Bioinformatics, 13:80.

See Also

ExpressionSet2weightedSubset, cghCall2weightedSubset

Examples

Run this code
# load data
data(pollackGE16)

# extract genomic information from ExpressionSet-object
chr <- fData(pollackGE16)[,1]
bpstart <- fData(pollackGE16)[,2]
bpend <- fData(pollackGE16)[,3]

# find unique genomic locations
uniqInfo <- uniqGenomicInfo(chr, bpstart, bpend, verbose = FALSE) 

Run the code above in your browser using DataLab