Arguments
CNdata
Object of class cghCall, containing (among others) annotion and call probabilities. Features should be matched with those of the accompanying ExpressionSet-object (as may be done using the matchAnn2Ann-function).
GEdata
Object of class ExpressionSet. Features should be matched with those of the accompanying cghCall-object (as may be done using the matchAnn2Ann-function).
testStatistic
Test statistic to be used, either "wcvm" or "wmw", the weighted Cramer-Von Mises and the weighted Mann-Whitney test statistic, respectively.
nGenes
Number of genes used for tuning.
nPerm
Number of permutation used for tuning.
minCallProbMass
A number inbetween 0 and 1. Genes with a marginal call probabilities in one of the classes smaller than minCallProbMass are discarded from further analysis. Effectively, this ensures identifiability of copy number effect on expression.
verbose
Boolean to suppress output, either FALSE and TRUE.