Arguments
Y
(High-dimensional) matrix. Rows are assumed to represent the samples, and columns represent the samples' genes or traits.
X
(High-dimensional) matrix. Rows are assumed to represent the samples, and columns represent the samples' genes or traits. The number of rows of X must be identical to that of Y.
method
Distributional assumption under which mutual information is to be estimated.
k
k-nearest neighbor parameter.
center
Logical indicator: should the columns (traits) of Y and X be centered at zero? Applied only under the normality assumption.
rescale
Logical indicator: should Y and X be rescaled to have the same scale? Applied only under the k-NN assumption.